# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.routing_api import RoutingApi


class TestRoutingApi(unittest.TestCase):
    """ RoutingApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.routing_api.RoutingApi()

    def tearDown(self):
        pass

    def test_delete_email_domains_domain_id(self):
        """
        Test case for delete_email_domains_domain_id

        Delete a domain
        """
        pass

    def test_delete_email_domains_domainname_routes_route_id(self):
        """
        Test case for delete_email_domains_domainname_routes_route_id

        Delete a route
        """
        pass

    def test_delete_queues_queue_id(self):
        """
        Test case for delete_queues_queue_id

        Delete a queue
        """
        pass

    def test_delete_queues_queue_id_users_member_id(self):
        """
        Test case for delete_queues_queue_id_users_member_id

        Delete queue member
        """
        pass

    def test_delete_queues_queue_id_wrapupcodes_code_id(self):
        """
        Test case for delete_queues_queue_id_wrapupcodes_code_id

        Delete a wrap-up code from a queue
        """
        pass

    def test_delete_skills_skill_id(self):
        """
        Test case for delete_skills_skill_id

        Delete Routing Skill
        """
        pass

    def test_delete_user_id_routingskills_skill_id(self):
        """
        Test case for delete_user_id_routingskills_skill_id

        Remove routing skill from user
        """
        pass

    def test_delete_utilization(self):
        """
        Test case for delete_utilization

        Delete utilization settings and revert to system defaults.
        """
        pass

    def test_delete_wrapupcodes_code_id(self):
        """
        Test case for delete_wrapupcodes_code_id

        Delete wrap-up code
        """
        pass

    def test_get_email_domains(self):
        """
        Test case for get_email_domains

        Get domains
        """
        pass

    def test_get_email_domains_domainname_routes(self):
        """
        Test case for get_email_domains_domainname_routes

        Get routes
        """
        pass

    def test_get_email_domains_domainname_routes_route_id(self):
        """
        Test case for get_email_domains_domainname_routes_route_id

        Get a route
        """
        pass

    def test_get_email_setup(self):
        """
        Test case for get_email_setup

        Get email setup
        """
        pass

    def test_get_queues(self):
        """
        Test case for get_queues

        Get list of queues.
        """
        pass

    def test_get_queues_queue_id(self):
        """
        Test case for get_queues_queue_id

        Get details about this queue.
        """
        pass

    def test_get_queues_queue_id_estimatedwaittime(self):
        """
        Test case for get_queues_queue_id_estimatedwaittime

        Get Estimated Wait Time
        """
        pass

    def test_get_queues_queue_id_users(self):
        """
        Test case for get_queues_queue_id_users

        Get the members of this queue
        """
        pass

    def test_get_queues_queue_id_wrapupcodes(self):
        """
        Test case for get_queues_queue_id_wrapupcodes

        Get the wrap-up codes for a queue
        """
        pass

    def test_get_skills(self):
        """
        Test case for get_skills

        Get the list of routing skills.
        """
        pass

    def test_get_skills_skill_id(self):
        """
        Test case for get_skills_skill_id

        Get Routing Skill
        """
        pass

    def test_get_user_id_routingskills(self):
        """
        Test case for get_user_id_routingskills

        List routing skills for user
        """
        pass

    def test_get_utilization(self):
        """
        Test case for get_utilization

        Get the utilization settings.
        """
        pass

    def test_get_wrapupcodes(self):
        """
        Test case for get_wrapupcodes

        Get list of wrapup codes.
        """
        pass

    def test_get_wrapupcodes_code_id(self):
        """
        Test case for get_wrapupcodes_code_id

        Get details about this wrap-up code.
        """
        pass

    def test_patch_queues_queue_id_users(self):
        """
        Test case for patch_queues_queue_id_users

        Join or unjoin a set of users for a queue
        """
        pass

    def test_patch_queues_queue_id_users_member_id(self):
        """
        Test case for patch_queues_queue_id_users_member_id

        Update the ring number of joined status for a User in a Queue
        """
        pass

    def test_post_email_domains(self):
        """
        Test case for post_email_domains

        Create a domain
        """
        pass

    def test_post_email_domains_domainname_routes(self):
        """
        Test case for post_email_domains_domainname_routes

        Create a route
        """
        pass

    def test_post_queues(self):
        """
        Test case for post_queues

        Create queue
        """
        pass

    def test_post_queues_observations_query(self):
        """
        Test case for post_queues_observations_query

        Query for queue observations
        """
        pass

    def test_post_queues_queue_id_users(self):
        """
        Test case for post_queues_queue_id_users

        Bulk add or delete up to 100 queue members
        """
        pass

    def test_post_queues_queue_id_wrapupcodes(self):
        """
        Test case for post_queues_queue_id_wrapupcodes

        Add up to 100 wrap-up codes to a queue
        """
        pass

    def test_post_skills(self):
        """
        Test case for post_skills

        Create Skill
        """
        pass

    def test_post_user_id_routingskills(self):
        """
        Test case for post_user_id_routingskills

        Add routing skill to user
        """
        pass

    def test_post_wrapupcodes(self):
        """
        Test case for post_wrapupcodes

        Create a wrap-up code
        """
        pass

    def test_put_email_domains_domainname_routes_route_id(self):
        """
        Test case for put_email_domains_domainname_routes_route_id

        Update a route
        """
        pass

    def test_put_queues_queue_id(self):
        """
        Test case for put_queues_queue_id

        Update a queue
        """
        pass

    def test_put_user_id_routingskills_skill_id(self):
        """
        Test case for put_user_id_routingskills_skill_id

        Update routing skill proficiency or state.
        """
        pass

    def test_put_utilization(self):
        """
        Test case for put_utilization

        Update the utilization settings.
        """
        pass

    def test_put_wrapupcodes_code_id(self):
        """
        Test case for put_wrapupcodes_code_id

        Update wrap-up code
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class CreateUser(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateUser - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'department': 'str',
            'email': 'str',
            'addresses': 'list[Contact]',
            'title': 'str',
            'password': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'department': 'department',
            'email': 'email',
            'addresses': 'addresses',
            'title': 'title',
            'password': 'password'
        }

        self._name = None
        self._department = None
        self._email = None
        self._addresses = None
        self._title = None
        self._password = None

    @property
    def name(self):
        """
        Gets the name of this CreateUser.
        User's full name

        :return: The name of this CreateUser.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateUser.
        User's full name

        :param name: The name of this CreateUser.
        :type: str
        """
        
        self._name = name

    @property
    def department(self):
        """
        Gets the department of this CreateUser.


        :return: The department of this CreateUser.
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """
        Sets the department of this CreateUser.


        :param department: The department of this CreateUser.
        :type: str
        """
        
        self._department = department

    @property
    def email(self):
        """
        Gets the email of this CreateUser.
        User's email and username

        :return: The email of this CreateUser.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this CreateUser.
        User's email and username

        :param email: The email of this CreateUser.
        :type: str
        """
        
        self._email = email

    @property
    def addresses(self):
        """
        Gets the addresses of this CreateUser.
        Email addresses and phone numbers for this user

        :return: The addresses of this CreateUser.
        :rtype: list[Contact]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this CreateUser.
        Email addresses and phone numbers for this user

        :param addresses: The addresses of this CreateUser.
        :type: list[Contact]
        """
        
        self._addresses = addresses

    @property
    def title(self):
        """
        Gets the title of this CreateUser.


        :return: The title of this CreateUser.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this CreateUser.


        :param title: The title of this CreateUser.
        :type: str
        """
        
        self._title = title

    @property
    def password(self):
        """
        Gets the password of this CreateUser.
        User's password

        :return: The password of this CreateUser.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this CreateUser.
        User's password

        :param password: The password of this CreateUser.
        :type: str
        """
        
        self._password = password

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class OrphanRecording(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        OrphanRecording - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'created_time': 'datetime',
            'recovered_time': 'datetime',
            'provider_type': 'str',
            'media_size_bytes': 'int',
            'media_type': 'str',
            'file_state': 'str',
            'provider_endpoint': 'Endpoint',
            'recording': 'Recording',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'created_time': 'createdTime',
            'recovered_time': 'recoveredTime',
            'provider_type': 'providerType',
            'media_size_bytes': 'mediaSizeBytes',
            'media_type': 'mediaType',
            'file_state': 'fileState',
            'provider_endpoint': 'providerEndpoint',
            'recording': 'recording',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._created_time = None
        self._recovered_time = None
        self._provider_type = None
        self._media_size_bytes = None
        self._media_type = None
        self._file_state = None
        self._provider_endpoint = None
        self._recording = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this OrphanRecording.
        The globally unique identifier for the object.

        :return: The id of this OrphanRecording.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this OrphanRecording.
        The globally unique identifier for the object.

        :param id: The id of this OrphanRecording.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this OrphanRecording.


        :return: The name of this OrphanRecording.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this OrphanRecording.


        :param name: The name of this OrphanRecording.
        :type: str
        """
        
        self._name = name

    @property
    def created_time(self):
        """
        Gets the created_time of this OrphanRecording.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_time of this OrphanRecording.
        :rtype: datetime
        """
        return self._created_time

    @created_time.setter
    def created_time(self, created_time):
        """
        Sets the created_time of this OrphanRecording.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_time: The created_time of this OrphanRecording.
        :type: datetime
        """
        
        self._created_time = created_time

    @property
    def recovered_time(self):
        """
        Gets the recovered_time of this OrphanRecording.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The recovered_time of this OrphanRecording.
        :rtype: datetime
        """
        return self._recovered_time

    @recovered_time.setter
    def recovered_time(self, recovered_time):
        """
        Sets the recovered_time of this OrphanRecording.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param recovered_time: The recovered_time of this OrphanRecording.
        :type: datetime
        """
        
        self._recovered_time = recovered_time

    @property
    def provider_type(self):
        """
        Gets the provider_type of this OrphanRecording.


        :return: The provider_type of this OrphanRecording.
        :rtype: str
        """
        return self._provider_type

    @provider_type.setter
    def provider_type(self, provider_type):
        """
        Sets the provider_type of this OrphanRecording.


        :param provider_type: The provider_type of this OrphanRecording.
        :type: str
        """
        allowed_values = ["EDGE", "CHAT", "EMAIL"]
        if provider_type not in allowed_values:
            raise ValueError(
                "Invalid value for `provider_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._provider_type = provider_type

    @property
    def media_size_bytes(self):
        """
        Gets the media_size_bytes of this OrphanRecording.


        :return: The media_size_bytes of this OrphanRecording.
        :rtype: int
        """
        return self._media_size_bytes

    @media_size_bytes.setter
    def media_size_bytes(self, media_size_bytes):
        """
        Sets the media_size_bytes of this OrphanRecording.


        :param media_size_bytes: The media_size_bytes of this OrphanRecording.
        :type: int
        """
        
        self._media_size_bytes = media_size_bytes

    @property
    def media_type(self):
        """
        Gets the media_type of this OrphanRecording.


        :return: The media_type of this OrphanRecording.
        :rtype: str
        """
        return self._media_type

    @media_type.setter
    def media_type(self, media_type):
        """
        Sets the media_type of this OrphanRecording.


        :param media_type: The media_type of this OrphanRecording.
        :type: str
        """
        allowed_values = ["CALL", "CHAT", "EMAIL"]
        if media_type not in allowed_values:
            raise ValueError(
                "Invalid value for `media_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._media_type = media_type

    @property
    def file_state(self):
        """
        Gets the file_state of this OrphanRecording.


        :return: The file_state of this OrphanRecording.
        :rtype: str
        """
        return self._file_state

    @file_state.setter
    def file_state(self, file_state):
        """
        Sets the file_state of this OrphanRecording.


        :param file_state: The file_state of this OrphanRecording.
        :type: str
        """
        allowed_values = ["ARCHIVED", "AVAILABLE", "DELETED", "RESTORED", "RESTORING", "UPLOADING"]
        if file_state not in allowed_values:
            raise ValueError(
                "Invalid value for `file_state`, must be one of {0}"
                .format(allowed_values)
            )

        self._file_state = file_state

    @property
    def provider_endpoint(self):
        """
        Gets the provider_endpoint of this OrphanRecording.


        :return: The provider_endpoint of this OrphanRecording.
        :rtype: Endpoint
        """
        return self._provider_endpoint

    @provider_endpoint.setter
    def provider_endpoint(self, provider_endpoint):
        """
        Sets the provider_endpoint of this OrphanRecording.


        :param provider_endpoint: The provider_endpoint of this OrphanRecording.
        :type: Endpoint
        """
        
        self._provider_endpoint = provider_endpoint

    @property
    def recording(self):
        """
        Gets the recording of this OrphanRecording.


        :return: The recording of this OrphanRecording.
        :rtype: Recording
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this OrphanRecording.


        :param recording: The recording of this OrphanRecording.
        :type: Recording
        """
        
        self._recording = recording

    @property
    def self_uri(self):
        """
        Gets the self_uri of this OrphanRecording.
        The URI for this object

        :return: The self_uri of this OrphanRecording.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this OrphanRecording.
        The URI for this object

        :param self_uri: The self_uri of this OrphanRecording.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class Evaluation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Evaluation - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'conversation': 'Conversation',
            'evaluation_form': 'EvaluationForm',
            'evaluator': 'User',
            'agent': 'User',
            'calibration': 'Calibration',
            'status': 'str',
            'answers': 'EvaluationScoringSet',
            'agent_has_read': 'bool',
            'release_date': 'datetime',
            'assigned_date': 'datetime',
            'changed_date': 'datetime',
            'queue': 'Queue',
            'never_release': 'bool',
            'resource_id': 'str',
            'resource_type': 'str',
            'redacted': 'bool',
            'is_scoring_index': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'conversation': 'conversation',
            'evaluation_form': 'evaluationForm',
            'evaluator': 'evaluator',
            'agent': 'agent',
            'calibration': 'calibration',
            'status': 'status',
            'answers': 'answers',
            'agent_has_read': 'agentHasRead',
            'release_date': 'releaseDate',
            'assigned_date': 'assignedDate',
            'changed_date': 'changedDate',
            'queue': 'queue',
            'never_release': 'neverRelease',
            'resource_id': 'resourceId',
            'resource_type': 'resourceType',
            'redacted': 'redacted',
            'is_scoring_index': 'isScoringIndex',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._conversation = None
        self._evaluation_form = None
        self._evaluator = None
        self._agent = None
        self._calibration = None
        self._status = None
        self._answers = None
        self._agent_has_read = False
        self._release_date = None
        self._assigned_date = None
        self._changed_date = None
        self._queue = None
        self._never_release = False
        self._resource_id = None
        self._resource_type = None
        self._redacted = False
        self._is_scoring_index = False
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Evaluation.
        The globally unique identifier for the object.

        :return: The id of this Evaluation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Evaluation.
        The globally unique identifier for the object.

        :param id: The id of this Evaluation.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Evaluation.


        :return: The name of this Evaluation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Evaluation.


        :param name: The name of this Evaluation.
        :type: str
        """
        
        self._name = name

    @property
    def conversation(self):
        """
        Gets the conversation of this Evaluation.


        :return: The conversation of this Evaluation.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this Evaluation.


        :param conversation: The conversation of this Evaluation.
        :type: Conversation
        """
        
        self._conversation = conversation

    @property
    def evaluation_form(self):
        """
        Gets the evaluation_form of this Evaluation.
        Evaluation form used for evaluation.

        :return: The evaluation_form of this Evaluation.
        :rtype: EvaluationForm
        """
        return self._evaluation_form

    @evaluation_form.setter
    def evaluation_form(self, evaluation_form):
        """
        Sets the evaluation_form of this Evaluation.
        Evaluation form used for evaluation.

        :param evaluation_form: The evaluation_form of this Evaluation.
        :type: EvaluationForm
        """
        
        self._evaluation_form = evaluation_form

    @property
    def evaluator(self):
        """
        Gets the evaluator of this Evaluation.


        :return: The evaluator of this Evaluation.
        :rtype: User
        """
        return self._evaluator

    @evaluator.setter
    def evaluator(self, evaluator):
        """
        Sets the evaluator of this Evaluation.


        :param evaluator: The evaluator of this Evaluation.
        :type: User
        """
        
        self._evaluator = evaluator

    @property
    def agent(self):
        """
        Gets the agent of this Evaluation.


        :return: The agent of this Evaluation.
        :rtype: User
        """
        return self._agent

    @agent.setter
    def agent(self, agent):
        """
        Sets the agent of this Evaluation.


        :param agent: The agent of this Evaluation.
        :type: User
        """
        
        self._agent = agent

    @property
    def calibration(self):
        """
        Gets the calibration of this Evaluation.


        :return: The calibration of this Evaluation.
        :rtype: Calibration
        """
        return self._calibration

    @calibration.setter
    def calibration(self, calibration):
        """
        Sets the calibration of this Evaluation.


        :param calibration: The calibration of this Evaluation.
        :type: Calibration
        """
        
        self._calibration = calibration

    @property
    def status(self):
        """
        Gets the status of this Evaluation.


        :return: The status of this Evaluation.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Evaluation.


        :param status: The status of this Evaluation.
        :type: str
        """
        allowed_values = ["PENDING", "INPROGRESS", "FINISHED"]
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status`, must be one of {0}"
                .format(allowed_values)
            )

        self._status = status

    @property
    def answers(self):
        """
        Gets the answers of this Evaluation.


        :return: The answers of this Evaluation.
        :rtype: EvaluationScoringSet
        """
        return self._answers

    @answers.setter
    def answers(self, answers):
        """
        Sets the answers of this Evaluation.


        :param answers: The answers of this Evaluation.
        :type: EvaluationScoringSet
        """
        
        self._answers = answers

    @property
    def agent_has_read(self):
        """
        Gets the agent_has_read of this Evaluation.


        :return: The agent_has_read of this Evaluation.
        :rtype: bool
        """
        return self._agent_has_read

    @agent_has_read.setter
    def agent_has_read(self, agent_has_read):
        """
        Sets the agent_has_read of this Evaluation.


        :param agent_has_read: The agent_has_read of this Evaluation.
        :type: bool
        """
        
        self._agent_has_read = agent_has_read

    @property
    def release_date(self):
        """
        Gets the release_date of this Evaluation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The release_date of this Evaluation.
        :rtype: datetime
        """
        return self._release_date

    @release_date.setter
    def release_date(self, release_date):
        """
        Sets the release_date of this Evaluation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param release_date: The release_date of this Evaluation.
        :type: datetime
        """
        
        self._release_date = release_date

    @property
    def assigned_date(self):
        """
        Gets the assigned_date of this Evaluation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The assigned_date of this Evaluation.
        :rtype: datetime
        """
        return self._assigned_date

    @assigned_date.setter
    def assigned_date(self, assigned_date):
        """
        Sets the assigned_date of this Evaluation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param assigned_date: The assigned_date of this Evaluation.
        :type: datetime
        """
        
        self._assigned_date = assigned_date

    @property
    def changed_date(self):
        """
        Gets the changed_date of this Evaluation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The changed_date of this Evaluation.
        :rtype: datetime
        """
        return self._changed_date

    @changed_date.setter
    def changed_date(self, changed_date):
        """
        Sets the changed_date of this Evaluation.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param changed_date: The changed_date of this Evaluation.
        :type: datetime
        """
        
        self._changed_date = changed_date

    @property
    def queue(self):
        """
        Gets the queue of this Evaluation.


        :return: The queue of this Evaluation.
        :rtype: Queue
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this Evaluation.


        :param queue: The queue of this Evaluation.
        :type: Queue
        """
        
        self._queue = queue

    @property
    def never_release(self):
        """
        Gets the never_release of this Evaluation.
        Signifies if the evaluation is never to be released. This cannot be set true if release date is also set.

        :return: The never_release of this Evaluation.
        :rtype: bool
        """
        return self._never_release

    @never_release.setter
    def never_release(self, never_release):
        """
        Sets the never_release of this Evaluation.
        Signifies if the evaluation is never to be released. This cannot be set true if release date is also set.

        :param never_release: The never_release of this Evaluation.
        :type: bool
        """
        
        self._never_release = never_release

    @property
    def resource_id(self):
        """
        Gets the resource_id of this Evaluation.
        Only used for email evaluations. Will be null for all other evaluations.

        :return: The resource_id of this Evaluation.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this Evaluation.
        Only used for email evaluations. Will be null for all other evaluations.

        :param resource_id: The resource_id of this Evaluation.
        :type: str
        """
        
        self._resource_id = resource_id

    @property
    def resource_type(self):
        """
        Gets the resource_type of this Evaluation.
        The type of resource. Only used for email evaluations. Will be null for evaluations on all other resources.

        :return: The resource_type of this Evaluation.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this Evaluation.
        The type of resource. Only used for email evaluations. Will be null for evaluations on all other resources.

        :param resource_type: The resource_type of this Evaluation.
        :type: str
        """
        allowed_values = ["EMAIL"]
        if resource_type not in allowed_values:
            raise ValueError(
                "Invalid value for `resource_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._resource_type = resource_type

    @property
    def redacted(self):
        """
        Gets the redacted of this Evaluation.
        Is only true when the user making the request does not have sufficient permissions to see evaluation

        :return: The redacted of this Evaluation.
        :rtype: bool
        """
        return self._redacted

    @redacted.setter
    def redacted(self, redacted):
        """
        Sets the redacted of this Evaluation.
        Is only true when the user making the request does not have sufficient permissions to see evaluation

        :param redacted: The redacted of this Evaluation.
        :type: bool
        """
        
        self._redacted = redacted

    @property
    def is_scoring_index(self):
        """
        Gets the is_scoring_index of this Evaluation.


        :return: The is_scoring_index of this Evaluation.
        :rtype: bool
        """
        return self._is_scoring_index

    @is_scoring_index.setter
    def is_scoring_index(self, is_scoring_index):
        """
        Sets the is_scoring_index of this Evaluation.


        :param is_scoring_index: The is_scoring_index of this Evaluation.
        :type: bool
        """
        
        self._is_scoring_index = is_scoring_index

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Evaluation.
        The URI for this object

        :return: The self_uri of this Evaluation.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Evaluation.
        The URI for this object

        :param self_uri: The self_uri of this Evaluation.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
OAuthApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class OAuthApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_clients_client_id(self, client_id, **kwargs):
        """
        Delete OAuth Client
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_clients_client_id(client_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str client_id: Client ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['client_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_clients_client_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'client_id' is set
        if ('client_id' not in params) or (params['client_id'] is None):
            raise ValueError("Missing the required parameter `client_id` when calling `delete_clients_client_id`")


        resource_path = '/api/v2/oauth/clients/{clientId}'.replace('{format}', 'json')
        path_params = {}
        if 'client_id' in params:
            path_params['clientId'] = params['client_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_clients(self, **kwargs):
        """
        The list of OAuth clients
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_clients(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: OAuthClientEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_clients" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/oauth/clients'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OAuthClientEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_clients_client_id(self, client_id, **kwargs):
        """
        Get OAuth Client
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_clients_client_id(client_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str client_id: Client ID (required)
        :return: OAuthClient
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['client_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_clients_client_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'client_id' is set
        if ('client_id' not in params) or (params['client_id'] is None):
            raise ValueError("Missing the required parameter `client_id` when calling `get_clients_client_id`")


        resource_path = '/api/v2/oauth/clients/{clientId}'.replace('{format}', 'json')
        path_params = {}
        if 'client_id' in params:
            path_params['clientId'] = params['client_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OAuthClient',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_clients(self, body, **kwargs):
        """
        Create OAuth client
        The OAuth Grant/Client is required in order to create an authentication token and gain access to PureCloud.  The preferred authorizedGrantTypes is 'CODE' which requires applications to send a client ID and client secret. This is typically a web server.  If the client is unable to secure the client secret then the 'TOKEN' grant type aka IMPLICIT should be used. This is would be for browser or mobile apps.  If a client is to be used outside of the context of a user then the 'CLIENT-CREDENTIALS' grant may be used. In this case the client must be granted roles  via the 'roleIds' field.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_clients(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param OAuthClient body: Client (required)
        :return: OAuthClient
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_clients" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_clients`")


        resource_path = '/api/v2/oauth/clients'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OAuthClient',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_clients_client_id_secret(self, client_id, **kwargs):
        """
        Regenerate Client Secret
        This operation will set the client secret to a randomly generated cryptographically random value. All clients must be updated with the new secret. This operation should be used with caution.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_clients_client_id_secret(client_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str client_id: Client ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['client_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_clients_client_id_secret" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'client_id' is set
        if ('client_id' not in params) or (params['client_id'] is None):
            raise ValueError("Missing the required parameter `client_id` when calling `post_clients_client_id_secret`")


        resource_path = '/api/v2/oauth/clients/{clientId}/secret'.replace('{format}', 'json')
        path_params = {}
        if 'client_id' in params:
            path_params['clientId'] = params['client_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_clients_client_id(self, client_id, body, **kwargs):
        """
        Update OAuth Client
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_clients_client_id(client_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str client_id: Client ID (required)
        :param OAuthClient body: Client (required)
        :return: OAuthClient
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['client_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_clients_client_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'client_id' is set
        if ('client_id' not in params) or (params['client_id'] is None):
            raise ValueError("Missing the required parameter `client_id` when calling `put_clients_client_id`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_clients_client_id`")


        resource_path = '/api/v2/oauth/clients/{clientId}'.replace('{format}', 'json')
        path_params = {}
        if 'client_id' in params:
            path_params['clientId'] = params['client_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OAuthClient',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.voicemail_api import VoicemailApi


class TestVoicemailApi(unittest.TestCase):
    """ VoicemailApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.voicemail_api.VoicemailApi()

    def tearDown(self):
        pass

    def test_delete_messages(self):
        """
        Test case for delete_messages

        Delete all voicemail messages
        """
        pass

    def test_delete_messages_message_id(self):
        """
        Test case for delete_messages_message_id

        Delete a message.
        """
        pass

    def test_get_mailbox(self):
        """
        Test case for get_mailbox

        Get mailbox information
        """
        pass

    def test_get_messages(self):
        """
        Test case for get_messages

        List voicemail messages
        """
        pass

    def test_get_messages_message_id(self):
        """
        Test case for get_messages_message_id

        Get message.
        """
        pass

    def test_get_messages_message_id_media(self):
        """
        Test case for get_messages_message_id_media

        Get media playback URI for this message
        """
        pass

    def test_get_policy(self):
        """
        Test case for get_policy

        Get a policy
        """
        pass

    def test_get_userpolicies_user_id(self):
        """
        Test case for get_userpolicies_user_id

        Get a user's voicemail policy
        """
        pass

    def test_patch_userpolicies_user_id(self):
        """
        Test case for patch_userpolicies_user_id

        Update a user's voicemail policy
        """
        pass

    def test_put_messages_message_id(self):
        """
        Test case for put_messages_message_id

        Update a message.
        """
        pass

    def test_put_policy(self):
        """
        Test case for put_policy

        Update a policy
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.greetings_api import GreetingsApi


class TestGreetingsApi(unittest.TestCase):
    """ GreetingsApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.greetings_api.GreetingsApi()

    def tearDown(self):
        pass

    def test_delete_greeting_id(self):
        """
        Test case for delete_greeting_id

        Deletes a Greeting with the given GreetingId
        """
        pass

    def test_get_defaults(self):
        """
        Test case for get_defaults

        Get an Organization's DefaultGreetingList
        """
        pass

    def test_get_greeting_id(self):
        """
        Test case for get_greeting_id

        Get a Greeting with the given GreetingId
        """
        pass

    def test_get_greeting_id_media(self):
        """
        Test case for get_greeting_id_media

        Get media playback URI for this greeting
        """
        pass

    def test_get_greetings(self):
        """
        Test case for get_greetings

        Gets an Organization's Greetings
        """
        pass

    def test_get_user_id_greetings(self):
        """
        Test case for get_user_id_greetings

        Get a list of the User's Greetings
        """
        pass

    def test_get_user_id_greetings_defaults(self):
        """
        Test case for get_user_id_greetings_defaults

        Grabs the list of Default Greetings given a User's ID
        """
        pass

    def test_post_greetings(self):
        """
        Test case for post_greetings

        Create a Greeting for an Organization
        """
        pass

    def test_post_user_id_greetings(self):
        """
        Test case for post_user_id_greetings

        Creates a Greeting for a User
        """
        pass

    def test_put_defaults(self):
        """
        Test case for put_defaults

        Update an Organization's DefaultGreetingList
        """
        pass

    def test_put_greeting_id(self):
        """
        Test case for put_greeting_id

        Updates the Greeting with the given GreetingId
        """
        pass

    def test_put_user_id_greetings_defaults(self):
        """
        Test case for put_user_id_greetings_defaults

        Updates the DefaultGreetingList of the specified User
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DialerRule(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerRule - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'order': 'int',
            'category': 'str',
            'conditions': 'list[Condition]',
            'actions': 'list[DialerAction]'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'order': 'order',
            'category': 'category',
            'conditions': 'conditions',
            'actions': 'actions'
        }

        self._id = None
        self._name = None
        self._order = None
        self._category = None
        self._conditions = None
        self._actions = None

    @property
    def id(self):
        """
        Gets the id of this DialerRule.
        The identifier of the rule

        :return: The id of this DialerRule.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DialerRule.
        The identifier of the rule

        :param id: The id of this DialerRule.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DialerRule.
        The name of the rule

        :return: The name of this DialerRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DialerRule.
        The name of the rule

        :param name: The name of this DialerRule.
        :type: str
        """
        
        self._name = name

    @property
    def order(self):
        """
        Gets the order of this DialerRule.
        The ranked order of the rule; rules are processed from lowest number to highest

        :return: The order of this DialerRule.
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        Sets the order of this DialerRule.
        The ranked order of the rule; rules are processed from lowest number to highest

        :param order: The order of this DialerRule.
        :type: int
        """
        
        self._order = order

    @property
    def category(self):
        """
        Gets the category of this DialerRule.
        The category of the rule

        :return: The category of this DialerRule.
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """
        Sets the category of this DialerRule.
        The category of the rule

        :param category: The category of this DialerRule.
        :type: str
        """
        allowed_values = ["DIALER_PRECALL", "DIALER_WRAPUP"]
        if category not in allowed_values:
            raise ValueError(
                "Invalid value for `category`, must be one of {0}"
                .format(allowed_values)
            )

        self._category = category

    @property
    def conditions(self):
        """
        Gets the conditions of this DialerRule.
        The list of rule conditions; all must evaluate to true to trigger the rule actions

        :return: The conditions of this DialerRule.
        :rtype: list[Condition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """
        Sets the conditions of this DialerRule.
        The list of rule conditions; all must evaluate to true to trigger the rule actions

        :param conditions: The conditions of this DialerRule.
        :type: list[Condition]
        """
        
        self._conditions = conditions

    @property
    def actions(self):
        """
        Gets the actions of this DialerRule.
        The list of rule actions to be taken if the conditions are true

        :return: The actions of this DialerRule.
        :rtype: list[DialerAction]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """
        Sets the actions of this DialerRule.
        The list of rule actions to be taken if the conditions are true

        :param actions: The actions of this DialerRule.
        :type: list[DialerAction]
        """
        
        self._actions = actions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DomainResourceConditionValue(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainResourceConditionValue - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'user': 'User',
            'queue': 'Queue',
            'value': 'str',
            'type': 'str'
        }

        self.attribute_map = {
            'user': 'user',
            'queue': 'queue',
            'value': 'value',
            'type': 'type'
        }

        self._user = None
        self._queue = None
        self._value = None
        self._type = None

    @property
    def user(self):
        """
        Gets the user of this DomainResourceConditionValue.


        :return: The user of this DomainResourceConditionValue.
        :rtype: User
        """
        return self._user

    @user.setter
    def user(self, user):
        """
        Sets the user of this DomainResourceConditionValue.


        :param user: The user of this DomainResourceConditionValue.
        :type: User
        """
        
        self._user = user

    @property
    def queue(self):
        """
        Gets the queue of this DomainResourceConditionValue.


        :return: The queue of this DomainResourceConditionValue.
        :rtype: Queue
        """
        return self._queue

    @queue.setter
    def queue(self, queue):
        """
        Sets the queue of this DomainResourceConditionValue.


        :param queue: The queue of this DomainResourceConditionValue.
        :type: Queue
        """
        
        self._queue = queue

    @property
    def value(self):
        """
        Gets the value of this DomainResourceConditionValue.


        :return: The value of this DomainResourceConditionValue.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this DomainResourceConditionValue.


        :param value: The value of this DomainResourceConditionValue.
        :type: str
        """
        
        self._value = value

    @property
    def type(self):
        """
        Gets the type of this DomainResourceConditionValue.


        :return: The type of this DomainResourceConditionValue.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DomainResourceConditionValue.


        :param type: The type of this DomainResourceConditionValue.
        :type: str
        """
        allowed_values = ["SCALAR", "VARIABLE", "USER", "QUEUE"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )

        self._type = type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class DID(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DID - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'phone_number': 'str',
            'did_pool': 'UriReference',
            'owner': 'UriReference',
            'owner_type': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'phone_number': 'phoneNumber',
            'did_pool': 'didPool',
            'owner': 'owner',
            'owner_type': 'ownerType',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._phone_number = None
        self._did_pool = None
        self._owner = None
        self._owner_type = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DID.
        The globally unique identifier for the object.

        :return: The id of this DID.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DID.
        The globally unique identifier for the object.

        :param id: The id of this DID.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DID.


        :return: The name of this DID.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DID.


        :param name: The name of this DID.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this DID.


        :return: The description of this DID.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DID.


        :param description: The description of this DID.
        :type: str
        """
        
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this DID.


        :return: The version of this DID.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DID.


        :param version: The version of this DID.
        :type: int
        """
        
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this DID.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this DID.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DID.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this DID.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DID.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this DID.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DID.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this DID.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this DID.


        :return: The modified_by of this DID.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this DID.


        :param modified_by: The modified_by of this DID.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this DID.


        :return: The created_by of this DID.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this DID.


        :param created_by: The created_by of this DID.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this DID.


        :return: The state of this DID.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this DID.


        :param state: The state of this DID.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )

        self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this DID.


        :return: The modified_by_app of this DID.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this DID.


        :param modified_by_app: The modified_by_app of this DID.
        :type: str
        """
        
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this DID.


        :return: The created_by_app of this DID.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this DID.


        :param created_by_app: The created_by_app of this DID.
        :type: str
        """
        
        self._created_by_app = created_by_app

    @property
    def phone_number(self):
        """
        Gets the phone_number of this DID.


        :return: The phone_number of this DID.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this DID.


        :param phone_number: The phone_number of this DID.
        :type: str
        """
        
        self._phone_number = phone_number

    @property
    def did_pool(self):
        """
        Gets the did_pool of this DID.


        :return: The did_pool of this DID.
        :rtype: UriReference
        """
        return self._did_pool

    @did_pool.setter
    def did_pool(self, did_pool):
        """
        Sets the did_pool of this DID.


        :param did_pool: The did_pool of this DID.
        :type: UriReference
        """
        
        self._did_pool = did_pool

    @property
    def owner(self):
        """
        Gets the owner of this DID.
        A Uri reference to the owner of this DID, which is either a User or an IVR

        :return: The owner of this DID.
        :rtype: UriReference
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this DID.
        A Uri reference to the owner of this DID, which is either a User or an IVR

        :param owner: The owner of this DID.
        :type: UriReference
        """
        
        self._owner = owner

    @property
    def owner_type(self):
        """
        Gets the owner_type of this DID.


        :return: The owner_type of this DID.
        :rtype: str
        """
        return self._owner_type

    @owner_type.setter
    def owner_type(self, owner_type):
        """
        Sets the owner_type of this DID.


        :param owner_type: The owner_type of this DID.
        :type: str
        """
        allowed_values = ["USER", "PHONE", "IVR_CONFIG", "GROUP"]
        if owner_type not in allowed_values:
            raise ValueError(
                "Invalid value for `owner_type`, must be one of {0}"
                .format(allowed_values)
            )

        self._owner_type = owner_type

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DID.
        The URI for this object

        :return: The self_uri of this DID.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DID.
        The URI for this object

        :param self_uri: The self_uri of this DID.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.alerting_api import AlertingApi


class TestAlertingApi(unittest.TestCase):
    """ AlertingApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.alerting_api.AlertingApi()

    def tearDown(self):
        pass

    def test_delete_interactionstats_alerts_alert_id(self):
        """
        Test case for delete_interactionstats_alerts_alert_id

        Delete an interaction stats alert
        """
        pass

    def test_delete_interactionstats_rules_rule_id(self):
        """
        Test case for delete_interactionstats_rules_rule_id

        Delete an interaction stats rule.
        """
        pass

    def test_get_interactionstats_alerts(self):
        """
        Test case for get_interactionstats_alerts

        Get interaction stats alert list.
        """
        pass

    def test_get_interactionstats_alerts_alert_id(self):
        """
        Test case for get_interactionstats_alerts_alert_id

        Get an interaction stats alert
        """
        pass

    def test_get_interactionstats_alerts_unread(self):
        """
        Test case for get_interactionstats_alerts_unread

        Gets user unread count of interaction stats alerts.
        """
        pass

    def test_get_interactionstats_rules(self):
        """
        Test case for get_interactionstats_rules

        Get an interaction stats rule list.
        """
        pass

    def test_get_interactionstats_rules_rule_id(self):
        """
        Test case for get_interactionstats_rules_rule_id

        Get an interaction stats rule.
        """
        pass

    def test_post_interactionstats_rules(self):
        """
        Test case for post_interactionstats_rules

        Create an interaction stats rule.
        """
        pass

    def test_put_interactionstats_alerts_alert_id(self):
        """
        Test case for put_interactionstats_alerts_alert_id

        Update an interaction stats alert read status
        """
        pass

    def test_put_interactionstats_rules_rule_id(self):
        """
        Test case for put_interactionstats_rules_rule_id

        Update an interaction stats rule
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

   ref: https://github.com/swagger-api/swagger-codegen
"""

from __future__ import absolute_import

import os
import sys
import unittest

import swagger_client
from swagger_client.rest import ApiException
from swagger_client.apis.fax_api import FaxApi


class TestFaxApi(unittest.TestCase):
    """ FaxApi unit test stubs """

    def setUp(self):
        self.api = swagger_client.apis.fax_api.FaxApi()

    def tearDown(self):
        pass

    def test_delete_documents_document_id(self):
        """
        Test case for delete_documents_document_id

        Delete a fax document.
        """
        pass

    def test_get_documents(self):
        """
        Test case for get_documents

        Get a list of fax documents.
        """
        pass

    def test_get_documents_document_id(self):
        """
        Test case for get_documents_document_id

        Get a document.
        """
        pass

    def test_get_documents_document_id_content(self):
        """
        Test case for get_documents_document_id_content

        Download a fax document.
        """
        pass

    def test_get_summary(self):
        """
        Test case for get_summary

        Get fax summary
        """
        pass

    def test_put_documents_document_id(self):
        """
        Test case for put_documents_document_id

        Update a fax document.
        """
        pass


if __name__ == '__main__':
    unittest.main()


# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class MeteredEvaluationAssignment(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MeteredEvaluationAssignment - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'evaluation_context_id': 'str',
            'evaluators': 'list[User]',
            'max_number_evaluations': 'int',
            'evaluation_form': 'EvaluationForm',
            'assign_to_active_user': 'bool',
            'time_interval': 'TimeInterval'
        }

        self.attribute_map = {
            'evaluation_context_id': 'evaluationContextId',
            'evaluators': 'evaluators',
            'max_number_evaluations': 'maxNumberEvaluations',
            'evaluation_form': 'evaluationForm',
            'assign_to_active_user': 'assignToActiveUser',
            'time_interval': 'timeInterval'
        }

        self._evaluation_context_id = None
        self._evaluators = None
        self._max_number_evaluations = None
        self._evaluation_form = None
        self._assign_to_active_user = False
        self._time_interval = None

    @property
    def evaluation_context_id(self):
        """
        Gets the evaluation_context_id of this MeteredEvaluationAssignment.


        :return: The evaluation_context_id of this MeteredEvaluationAssignment.
        :rtype: str
        """
        return self._evaluation_context_id

    @evaluation_context_id.setter
    def evaluation_context_id(self, evaluation_context_id):
        """
        Sets the evaluation_context_id of this MeteredEvaluationAssignment.


        :param evaluation_context_id: The evaluation_context_id of this MeteredEvaluationAssignment.
        :type: str
        """
        
        self._evaluation_context_id = evaluation_context_id

    @property
    def evaluators(self):
        """
        Gets the evaluators of this MeteredEvaluationAssignment.


        :return: The evaluators of this MeteredEvaluationAssignment.
        :rtype: list[User]
        """
        return self._evaluators

    @evaluators.setter
    def evaluators(self, evaluators):
        """
        Sets the evaluators of this MeteredEvaluationAssignment.


        :param evaluators: The evaluators of this MeteredEvaluationAssignment.
        :type: list[User]
        """
        
        self._evaluators = evaluators

    @property
    def max_number_evaluations(self):
        """
        Gets the max_number_evaluations of this MeteredEvaluationAssignment.


        :return: The max_number_evaluations of this MeteredEvaluationAssignment.
        :rtype: int
        """
        return self._max_number_evaluations

    @max_number_evaluations.setter
    def max_number_evaluations(self, max_number_evaluations):
        """
        Sets the max_number_evaluations of this MeteredEvaluationAssignment.


        :param max_number_evaluations: The max_number_evaluations of this MeteredEvaluationAssignment.
        :type: int
        """
        
        self._max_number_evaluations = max_number_evaluations

    @property
    def evaluation_form(self):
        """
        Gets the evaluation_form of this MeteredEvaluationAssignment.


        :return: The evaluation_form of this MeteredEvaluationAssignment.
        :rtype: EvaluationForm
        """
        return self._evaluation_form

    @evaluation_form.setter
    def evaluation_form(self, evaluation_form):
        """
        Sets the evaluation_form of this MeteredEvaluationAssignment.


        :param evaluation_form: The evaluation_form of this MeteredEvaluationAssignment.
        :type: EvaluationForm
        """
        
        self._evaluation_form = evaluation_form

    @property
    def assign_to_active_user(self):
        """
        Gets the assign_to_active_user of this MeteredEvaluationAssignment.


        :return: The assign_to_active_user of this MeteredEvaluationAssignment.
        :rtype: bool
        """
        return self._assign_to_active_user

    @assign_to_active_user.setter
    def assign_to_active_user(self, assign_to_active_user):
        """
        Sets the assign_to_active_user of this MeteredEvaluationAssignment.


        :param assign_to_active_user: The assign_to_active_user of this MeteredEvaluationAssignment.
        :type: bool
        """
        
        self._assign_to_active_user = assign_to_active_user

    @property
    def time_interval(self):
        """
        Gets the time_interval of this MeteredEvaluationAssignment.


        :return: The time_interval of this MeteredEvaluationAssignment.
        :rtype: TimeInterval
        """
        return self._time_interval

    @time_interval.setter
    def time_interval(self, time_interval):
        """
        Sets the time_interval of this MeteredEvaluationAssignment.


        :param time_interval: The time_interval of this MeteredEvaluationAssignment.
        :type: TimeInterval
        """
        
        self._time_interval = time_interval

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class PermissionCollectionEntityListing(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PermissionCollectionEntityListing - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'page_size': 'int',
            'page_number': 'int',
            'total': 'int',
            'entities': 'list[DomainPermissionCollection]',
            'self_uri': 'str',
            'last_uri': 'str',
            'first_uri': 'str',
            'previous_uri': 'str',
            'next_uri': 'str',
            'page_count': 'int'
        }

        self.attribute_map = {
            'page_size': 'pageSize',
            'page_number': 'pageNumber',
            'total': 'total',
            'entities': 'entities',
            'self_uri': 'selfUri',
            'last_uri': 'lastUri',
            'first_uri': 'firstUri',
            'previous_uri': 'previousUri',
            'next_uri': 'nextUri',
            'page_count': 'pageCount'
        }

        self._page_size = None
        self._page_number = None
        self._total = None
        self._entities = None
        self._self_uri = None
        self._last_uri = None
        self._first_uri = None
        self._previous_uri = None
        self._next_uri = None
        self._page_count = None

    @property
    def page_size(self):
        """
        Gets the page_size of this PermissionCollectionEntityListing.


        :return: The page_size of this PermissionCollectionEntityListing.
        :rtype: int
        """
        return self._page_size

    @page_size.setter
    def page_size(self, page_size):
        """
        Sets the page_size of this PermissionCollectionEntityListing.


        :param page_size: The page_size of this PermissionCollectionEntityListing.
        :type: int
        """
        
        self._page_size = page_size

    @property
    def page_number(self):
        """
        Gets the page_number of this PermissionCollectionEntityListing.


        :return: The page_number of this PermissionCollectionEntityListing.
        :rtype: int
        """
        return self._page_number

    @page_number.setter
    def page_number(self, page_number):
        """
        Sets the page_number of this PermissionCollectionEntityListing.


        :param page_number: The page_number of this PermissionCollectionEntityListing.
        :type: int
        """
        
        self._page_number = page_number

    @property
    def total(self):
        """
        Gets the total of this PermissionCollectionEntityListing.


        :return: The total of this PermissionCollectionEntityListing.
        :rtype: int
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this PermissionCollectionEntityListing.


        :param total: The total of this PermissionCollectionEntityListing.
        :type: int
        """
        
        self._total = total

    @property
    def entities(self):
        """
        Gets the entities of this PermissionCollectionEntityListing.


        :return: The entities of this PermissionCollectionEntityListing.
        :rtype: list[DomainPermissionCollection]
        """
        return self._entities

    @entities.setter
    def entities(self, entities):
        """
        Sets the entities of this PermissionCollectionEntityListing.


        :param entities: The entities of this PermissionCollectionEntityListing.
        :type: list[DomainPermissionCollection]
        """
        
        self._entities = entities

    @property
    def self_uri(self):
        """
        Gets the self_uri of this PermissionCollectionEntityListing.


        :return: The self_uri of this PermissionCollectionEntityListing.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this PermissionCollectionEntityListing.


        :param self_uri: The self_uri of this PermissionCollectionEntityListing.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def last_uri(self):
        """
        Gets the last_uri of this PermissionCollectionEntityListing.


        :return: The last_uri of this PermissionCollectionEntityListing.
        :rtype: str
        """
        return self._last_uri

    @last_uri.setter
    def last_uri(self, last_uri):
        """
        Sets the last_uri of this PermissionCollectionEntityListing.


        :param last_uri: The last_uri of this PermissionCollectionEntityListing.
        :type: str
        """
        
        self._last_uri = last_uri

    @property
    def first_uri(self):
        """
        Gets the first_uri of this PermissionCollectionEntityListing.


        :return: The first_uri of this PermissionCollectionEntityListing.
        :rtype: str
        """
        return self._first_uri

    @first_uri.setter
    def first_uri(self, first_uri):
        """
        Sets the first_uri of this PermissionCollectionEntityListing.


        :param first_uri: The first_uri of this PermissionCollectionEntityListing.
        :type: str
        """
        
        self._first_uri = first_uri

    @property
    def previous_uri(self):
        """
        Gets the previous_uri of this PermissionCollectionEntityListing.


        :return: The previous_uri of this PermissionCollectionEntityListing.
        :rtype: str
        """
        return self._previous_uri

    @previous_uri.setter
    def previous_uri(self, previous_uri):
        """
        Sets the previous_uri of this PermissionCollectionEntityListing.


        :param previous_uri: The previous_uri of this PermissionCollectionEntityListing.
        :type: str
        """
        
        self._previous_uri = previous_uri

    @property
    def next_uri(self):
        """
        Gets the next_uri of this PermissionCollectionEntityListing.


        :return: The next_uri of this PermissionCollectionEntityListing.
        :rtype: str
        """
        return self._next_uri

    @next_uri.setter
    def next_uri(self, next_uri):
        """
        Sets the next_uri of this PermissionCollectionEntityListing.


        :param next_uri: The next_uri of this PermissionCollectionEntityListing.
        :type: str
        """
        
        self._next_uri = next_uri

    @property
    def page_count(self):
        """
        Gets the page_count of this PermissionCollectionEntityListing.


        :return: The page_count of this PermissionCollectionEntityListing.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this PermissionCollectionEntityListing.


        :param page_count: The page_count of this PermissionCollectionEntityListing.
        :type: int
        """
        
        self._page_count = page_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re


class EvaluationScoringSet(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EvaluationScoringSet - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'total_score': 'float',
            'total_critical_score': 'float',
            'question_group_scores': 'list[QuestionGroupScore]',
            'any_failed_kill_questions': 'bool',
            'comments': 'str',
            'agent_comments': 'str'
        }

        self.attribute_map = {
            'total_score': 'totalScore',
            'total_critical_score': 'totalCriticalScore',
            'question_group_scores': 'questionGroupScores',
            'any_failed_kill_questions': 'anyFailedKillQuestions',
            'comments': 'comments',
            'agent_comments': 'agentComments'
        }

        self._total_score = None
        self._total_critical_score = None
        self._question_group_scores = None
        self._any_failed_kill_questions = False
        self._comments = None
        self._agent_comments = None

    @property
    def total_score(self):
        """
        Gets the total_score of this EvaluationScoringSet.


        :return: The total_score of this EvaluationScoringSet.
        :rtype: float
        """
        return self._total_score

    @total_score.setter
    def total_score(self, total_score):
        """
        Sets the total_score of this EvaluationScoringSet.


        :param total_score: The total_score of this EvaluationScoringSet.
        :type: float
        """
        
        self._total_score = total_score

    @property
    def total_critical_score(self):
        """
        Gets the total_critical_score of this EvaluationScoringSet.


        :return: The total_critical_score of this EvaluationScoringSet.
        :rtype: float
        """
        return self._total_critical_score

    @total_critical_score.setter
    def total_critical_score(self, total_critical_score):
        """
        Sets the total_critical_score of this EvaluationScoringSet.


        :param total_critical_score: The total_critical_score of this EvaluationScoringSet.
        :type: float
        """
        
        self._total_critical_score = total_critical_score

    @property
    def question_group_scores(self):
        """
        Gets the question_group_scores of this EvaluationScoringSet.


        :return: The question_group_scores of this EvaluationScoringSet.
        :rtype: list[QuestionGroupScore]
        """
        return self._question_group_scores

    @question_group_scores.setter
    def question_group_scores(self, question_group_scores):
        """
        Sets the question_group_scores of this EvaluationScoringSet.


        :param question_group_scores: The question_group_scores of this EvaluationScoringSet.
        :type: list[QuestionGroupScore]
        """
        
        self._question_group_scores = question_group_scores

    @property
    def any_failed_kill_questions(self):
        """
        Gets the any_failed_kill_questions of this EvaluationScoringSet.


        :return: The any_failed_kill_questions of this EvaluationScoringSet.
        :rtype: bool
        """
        return self._any_failed_kill_questions

    @any_failed_kill_questions.setter
    def any_failed_kill_questions(self, any_failed_kill_questions):
        """
        Sets the any_failed_kill_questions of this EvaluationScoringSet.


        :param any_failed_kill_questions: The any_failed_kill_questions of this EvaluationScoringSet.
        :type: bool
        """
        
        self._any_failed_kill_questions = any_failed_kill_questions

    @property
    def comments(self):
        """
        Gets the comments of this EvaluationScoringSet.


        :return: The comments of this EvaluationScoringSet.
        :rtype: str
        """
        return self._comments

    @comments.setter
    def comments(self, comments):
        """
        Sets the comments of this EvaluationScoringSet.


        :param comments: The comments of this EvaluationScoringSet.
        :type: str
        """
        
        self._comments = comments

    @property
    def agent_comments(self):
        """
        Gets the agent_comments of this EvaluationScoringSet.


        :return: The agent_comments of this EvaluationScoringSet.
        :rtype: str
        """
        return self._agent_comments

    @agent_comments.setter
    def agent_comments(self, agent_comments):
        """
        Sets the agent_comments of this EvaluationScoringSet.


        :param agent_comments: The agent_comments of this EvaluationScoringSet.
        :type: str
        """
        
        self._agent_comments = agent_comments

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

